/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/java/org/apache/commons/resources/impl/BasicMessage.java,v 1.9 2004/03/27 21:34:09 dgraham Exp $
 * $Revision: 1.9 $
 * $Date: 2004/03/27 21:34:09 $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.io.Serializable;

import org.apache.commons.resources.Message;

/**
 * A basic implementation of the Message interface.
 * <p>
 * Orginally based on org.apache.http.action.ActionMessage, Revision 1.5.
 */
public class BasicMessage implements Serializable, Message {
    
    /**
     * The message key for this message.
     */
    protected String key = null;

    /**
     * The replacement values for this mesasge.
     */
    protected Object[] values = null;

    public BasicMessage() {
        super();
    }
    
    /**
     * Construct an action message with no replacement values.
     *
     * @param key Message key for this message
     */
    public BasicMessage(String key) {

        this.key = key;
        this.values = null;

    }

    /**
     * Construct an action message with the specified replacement values.
     *
     * @param key Message key for this message
     * @param value0 First replacement value
     */
    public BasicMessage(String key, Object value0) {

        this.key = key;
        this.values = new Object[]{value0};

    }

    /**
     * Construct an action message with the specified replacement values.
     *
     * @param key Message key for this message
     * @param value0 First replacement value
     * @param value1 Second replacement value
     */
    public BasicMessage(String key, Object value0, Object value1) {

        this.key = key;
        this.values = new Object[]{value0, value1};

    }

    /**
     * Construct an action message with the specified replacement values.
     *
     * @param key Message key for this message
     * @param value0 First replacement value
     * @param value1 Second replacement value
     * @param value2 Third replacement value
     */
    public BasicMessage(String key, Object value0, Object value1,
                        Object value2) {

        this.key = key;
        this.values = new Object[]{value0, value1, value2};

    }

    /**
     * Construct an action message with the specified replacement values.
     *
     * @param key Message key for this message
     * @param value0 First replacement value
     * @param value1 Second replacement value
     * @param value2 Third replacement value
     * @param value3 Fourth replacement value
     */
    public BasicMessage(String key, Object value0, Object value1,
                        Object value2, Object value3) {

        this.key = key;
        this.values = new Object[]{value0, value1, value2, value3};
    }

    /**
     * Construct an action message with the specified replacement values.
     *
     * @param key Message key for this message
     * @param values Array of replacement values
     */
    public BasicMessage(String key, Object[] values) {
        this.key = key;
        this.values = values;
    }

    // See interface for JavaDoc
    public String getKey() {
        return (this.key);
    }

    // See interface for JavaDoc
    public Object[] getValues() {
        return (this.values);
    }

    /**
     * Returns a String in the format: key[value0, value1, etc].
     * @see java.lang.Object#toString()
     */
    public String toString() {
        StringBuffer buff = new StringBuffer();
        buff.append(this.key);
        buff.append("[");

        if (this.values != null) {

            for (int i = 0; i < this.values.length; i++) {

                buff.append(this.values[i]);

                // don't append comma to last entry
                if (i < this.values.length - 1) {
                    buff.append(", ");
                }
                
            }
        }

        buff.append("]");

        return buff.toString();
    }

}
