/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/java/org/apache/commons/resources/impl/HibernateResources.java,v 1.1 2004/06/11 02:43:48 jmitchell Exp $
 * $Revision: 1.1 $
 * $Date: 2004/06/11 02:43:48 $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;

import net.sf.hibernate.HibernateException;
import net.sf.hibernate.Query;
import net.sf.hibernate.Session;
import net.sf.hibernate.SessionFactory;
import net.sf.hibernate.cfg.Configuration;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.resources.ResourcesException;

/**
 * <p>Concrete implementation of 
 * {@link org.apache.commons.resources.Resources} that wraps a 
 * Hibernate session and retrieves values for the given 
 * <code>Locale</code> and have name suffixes reflecting the 
 * <code>Locale</code> for which the document's messages apply.
 * For this specific implementation, resources are looked up in 
 * a hierarchy of database values in a manner identical to that 
 * performed by <code>java.util.ResourceBundle.getBundle().</code>.
 * </p>
 *
 * <p>The base URL passed to our constructor must contain the base name
 * of a the hibernate configuration file.</p>
 *
 * @author James Mitchell
 * @version $Revision: 1.1 $ $Date: 2004/06/11 02:43:48 $
 */
public class HibernateResources extends CollectionResourcesBase {

    /**
     * <p>The <code>Log</code> instance for this class.</p>
     */
    private static final Log log = LogFactory.getLog(HibernateResources.class);

    // ----------------------------------------------------------- Constructors

    /**
     * <p>Create a new 
     * {@link org.apache.commons.resources.Resources} instance with the specified
     * logical name and base resource URL.</p>
     *
     * @param name Logical name of the new instance
     * @param base Base URL of the Hibernate configuration file.
     */
    public HibernateResources(String name, String base) {
        super(name, base);
    }


    // ------------------------------------------------------ Protected Methods


    /**
     * <p>Return a <code>Map</code> containing the name-value mappings for
     * the specified base URL and requested <code>Locale</code>, if there
     * are any.  If there are no defined mappings for the specified
     * <code>Locale</code>, return an empty <code>Map</code> instead.</p>
     *
     * <p>Concrete subclasses must override this method to perform the
     * appropriate lookup.  A typical implementation will construct an
     * absolute URL based on the specified base URL and <code>Locale</code>,
     * retrieve the specified resource file (if any), and parse it into
     * a <code>Map</code> structure.</p>
     *
     * <p>Caching of previously retrieved <code>Map</code>s (if any) should
     * be performed by callers of this method.  Therefore, this method should
     * always attempt to retrieve the specified resource and load it
     * appropriately.</p>
     *
     * @param baseUrl Base URL of the resource files for this 
     * {@link org.apache.commons.resources.Resources} instance
     * @param locale <code>Locale</code> for which name-value mappings
     *  are requested
     */
    protected Map getLocaleMap(String baseUrl, Locale locale) {

        if (log.isDebugEnabled()) {
            log.debug("Loading database configuration '" + locale + "' resources from base '" +
                    baseUrl + "'");
        }
        
        Properties props = new Properties();
        Session session = null;
        try {            
            // TODO - change this to load the specified hibernate config file (baseUrl)
            SessionFactory sessionFactory =
                new Configuration().configure().buildSessionFactory();
            session = sessionFactory.openSession();
            Query q = session.getNamedQuery("QueryByLocale");
            q.setString(0, locale.toString());
    		q.list();
    		List msgs = q.list();
    		for (Iterator iter = msgs.iterator(); iter.hasNext();) {
                HibernateBasicMessage msg = (HibernateBasicMessage) iter.next();
                props.put(msg.getKey(), msg.getValue());
            }
    		session.close();
        
        } catch (HibernateException e) {
            e.printStackTrace();
        }

        return props;

        

    }


    public void init() throws ResourcesException {
        super.init();
    }
}
