/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/test/org/apache/commons/resources/impl/ResourceBundleResourcesTestCase.java,v 1.9 2004/03/27 21:34:09 dgraham Exp $
 * $Revision: 1.9 $
 * $Date: 2004/03/27 21:34:09 $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.commons.resources.Resources;
import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesKeyException;

/**
 * <p>Unit tests for
 * <code>org.apache.commons.resources.impl.ResourceBundleResources</code>.
 * </p>
 */
public class ResourceBundleResourcesTestCase
    extends ResourceBundleResourcesFactoryTestCase {


    // ----------------------------------------------------- Instance Variables


    // The Resources instance to be tested
    protected Resources resources = null;


    // ----------------------------------------------------------- Constructors


    public ResourceBundleResourcesTestCase(String name) {
        super(name);
    }


    // --------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case
    public void setUp() throws Exception {
        super.setUp();
        resources = factory.getResources(NAME, CONFIG);
    }

    // Return the tests included in this test suite
    public static Test suite() {
        return (new TestSuite(ResourceBundleResourcesTestCase.class));
    }

    // Tear down the instance variables required by this test case
    public void tearDown() {
        resources = null;
        super.tearDown();
    }


    // ------------------------------------------------ Individual Test Methods


    // Test retrieving Strings that should be inherited from parent Locales
    public void testInherit() throws Exception {

        Locale locale = null;

        locale = new Locale("en", "US");
        assertEquals("en_US inherit value",
                     "[en] INHERIT",
                     resources.getString("test.inherit", locale, null));

        locale = new Locale("fr", "FR");
        assertEquals("fr_FR inherit value",
                     "[fr] INHERIT",
                     resources.getString("test.inherit", locale, null));

    }


    // Test retrieving missing resource keys
    public void testMissing() throws Exception {

        Locale locale = new Locale("en","");
        try {
            resources.setReturnNull(false);
            resources.getString("test.missing", locale, null);
            fail("Should have thrown ResourcesException");
        } catch (ResourcesKeyException e) {
            ; // Expected result
        }
        try {
            resources.setReturnNull(true);
            String value = resources.getString("test.missing", locale, null);
            assertTrue("Should have returned null", value == null);
        } catch (ResourcesException e) {
            fail("Should have returned null");
        }

    }


    // Test the characteristics of a newly created instance
    public void testPristine() {
        assertNotNull(resources);
        assertEquals("Correct name", NAME, resources.getName());
        assertEquals("Correct base", CONFIG,
                     ((ResourceBundleResources) resources).getBase());
    }


    // Test retrieving Locale-specific Strings explicitly
    public void testSpecific() throws Exception {

        Locale locale = null;

        locale = new Locale("en","");
        assertEquals("en specific value",
                     "[en] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("en", "US");
        assertEquals("en_US specific value",
                     "[en_US] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("fr","");
        assertEquals("fr specific value",
                     "[fr] SPECIFIC",
                     resources.getString("test.specific", locale, null));

    }


}
